#
# spec file for package socket_wrapper
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


############################# NOTE ##################################
#
# This is a special library. You are not able to link this library.
# Do NOT create library package or a devel package!
#
############################# NOTE ##################################

Name:           socket_wrapper
Version:        1.4.4
Release:        1.1
Summary:        A library passing all socket communications through Unix sockets
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://cwrap.org/
#
Source0:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz
Source1:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz.asc
Source2:        socket_wrapper.keyring
Source3:        %{name}-rpmlintrc
#
BuildRequires:  cmake
BuildRequires:  pkg-config
BuildRequires:  cmake(cmocka)

%description
socket_wrapper helps client/server software development to gain functional test
coverage. It can run several instances of a software stack on the same machine
and perform functional testing of network configurations locally.

To use it, set the following environment variables:

LD_PRELOAD=libsocket_wrapper.so
SOCKET_WRAPPER_DIR=/path/to/swrap_dir

%package -n libsocket_wrapper_noop0
Summary:        A library providing dummies for socket_wrapper

%description -n libsocket_wrapper_noop0
Applications with the need to call socket_wrapper_enabled() should link against
-lsocket_wrapper_noop in order to resolve the symbol at link time.

%package -n libsocket_wrapper_noop-devel
Summary:        Development headers for libsocket_wrapper_noop
Requires:       libsocket_wrapper_noop0 = %{version}

%description -n libsocket_wrapper_noop-devel
Development headers for applications with the need to call
socket_wrapper_enabled().

%prep
%autosetup -p1

%build
%cmake \
  -DUNIT_TESTING=ON

%make_build VERBOSE=1

%install
%cmake_install

%check
%ctest

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post -n libsocket_wrapper_noop0 -p /sbin/ldconfig

%postun -n libsocket_wrapper_noop0 -p /sbin/ldconfig

%files
%doc AUTHORS README.md CHANGELOG
%license LICENSE
%{_libdir}/libsocket_wrapper.so.*
%{_mandir}/man1/socket_wrapper.1*
%{_libdir}/libsocket_wrapper.so
%dir %{_libdir}/cmake/socket_wrapper
%{_libdir}/cmake/socket_wrapper/socket_wrapper-config-version.cmake
%{_libdir}/cmake/socket_wrapper/socket_wrapper-config.cmake
%{_libdir}/pkgconfig/socket_wrapper.pc

%files -n libsocket_wrapper_noop0
%{_libdir}/libsocket_wrapper_noop.so.*

%files -n libsocket_wrapper_noop-devel
%{_includedir}/socket_wrapper.h
%{_libdir}/libsocket_wrapper_noop.so
%{_libdir}/cmake/socket_wrapper/socket_wrapper_noop-config*.cmake
%{_libdir}/pkgconfig/socket_wrapper_noop.pc

%changelog
* Wed Jan 22 2025 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.4.4
  * Fixed setsockopt(SO_REUSEPORT) with glibc 2.40
* Thu Jun 13 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.4.3
  * Added support to find libc via LIBC_SO define
  * Fixed uid_wrapper running with jemalloc compiled binaries
  * Fixed socket_wrapper interaction test
  * Fixed thread sanitizer on modern Linux Kernels
* Thu Aug 31 2023 Andreas Schneider <asn@cryptomilk.org>
- Update BuildRequires
* Thu Jun 29 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.4.2
  * Fix LFS issues on 32bit platforms
* Wed Jun 21 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.4.1
  * Fixed issue with fnctl() on 32bit
  * Added openat64() to detect stale fds
- Remove socket_wrapper-fix-cmocka-1.1.6+-support.patch
* Thu Feb 23 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix building with cmocka >= 1.1.6
  * Added socket_wrapper-fix-cmocka-1.1.6+-support.patch
* Wed Jan 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.4.0
  * Added support for sendmmsg()/recvmmsg()
  * Added support for handling close, recvmmsg and sendmmsg syscalls
  * Added support to interact with uid_wrapper syscall()
  * Improved IP address tracing output
* Thu Nov 24 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.5
  * Inject O_LARGEFILE as needed on 32bit
  * pkgconfig: Fix path to libsocket_wrapper.so
  * Fix -Wcast-qual warnings
  * Fix dclose(RTLD_NEXT)
* Thu Jul 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.4
  * Fixed TOCTOU issue with udp auto binding
  * Fixed running on FreeBSD
* Wed Mar 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.3
  * Added public libsocket_wrapper_noop library
  * Added wrapper for wrap __close_nocancel()
  * Fixed possible deadlock in swrap_pcap_dump_packet()
  * Fixed issue when writing pcap files
* Wed Feb 10 2021 Jan Engelhardt <jengelh@inai.de>
- Drop obsolete specfile constructs. Remove extraneous Recommends
  (no other package of the kind would have these).
- Trim filler wording from descriptions.
* Wed Feb 10 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.2
  * https://gitlab.com/cwrap/socket_wrapper/-/blob/socket_wrapper-1.3.2/CHANGELOG
* Fri Feb  5 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.1
  * Fixed copy on write leak of ~38M for every fork
  * Fixed issue with accept() on FreeBSD
  * Fixed fd-passing on 32bit platforms
  * Fixed invalid read in swrap_sendmsg_unix_scm_rights()
* Wed Feb  3 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.0
  * https://gitlab.com/cwrap/socket_wrapper/-/blob/socket_wrapper-1.3.0/CHANGELOG
* Mon Jun 22 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.5
  * https://gitlab.com/cwrap/socket_wrapper/-/blob/master/CHANGELOG
* Tue Mar 24 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.4
  * https://gitlab.com/cwrap/socket_wrapper/-/blob/master/CHANGELOG
* Thu Oct 31 2019 Andreas Schneider <asn@cryptomilk.org>
- Some spec file cleanups
* Wed Aug 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Change Requires to Recommends for cmake and pkgconf
* Thu Mar 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.3
  * Fixed missing NULL check for socket_wrapper_dir()
  * Fixes building in Samba source tree
* Thu Mar 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.2
  * Added environment variable to disable deep binding
  * Fixed installation of socket_wrapper
  * Fixed several small bugs
* Wed Nov 14 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.1
  * Removed error message to fix applications doing stupid things
* Tue Nov 13 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.0
  * Added threading support
  * Moved to modern cmake
  * Several smaller bugfixes
* Mon Dec  4 2017 asn@cryptomilk.org
- Update to version 1.1.9
  * Fixed thread - signal deadlock issue
* Fri Oct 13 2017 asn@cryptomilk.org
- Update to version 1.1.8
  * Added support for openat()
  * Added support for open64() and fopen64()
  * Always enabled logging support
  * Increased maximum for wrapped interfaces to 64
  * Improved fd duplication code
  * Fixed strict-aliasing issues
  * Fixed some use after free issues
  * Fixed issues on ppc64le
* Tue May 31 2016 asn@cryptomilk.org
- Update to version 1.1.7
  * Added support for accept4()
  * Added support for OpenBSD
  * Fixed sendto() with UDP and a connected socket
  * Fixed AF_RAWLINK sockets
* Mon Mar 21 2016 asn@cryptomilk.org
- Update to version 1.1.6
  * Added a wrapper for write()
  * Added support for automatic binding of ephemeral ports
  * Fixed recvmsg() with UDP
  * Fixed AF_NETLINK sockets
* Sun Feb 14 2016 jengelh@inai.de
- Editorial fixes to the description
* Thu Oct 15 2015 asn@cryptomilk.org
- Update to version 1.1.5
  * Added support for TCP_NODELAY in setsockopt/getsockopt
  * Fixed cmsg space calculation
* Wed Sep  2 2015 asn@cryptomilk.org
- Update to version 1.1.4
  * Fixed handling of msg_name in recvmsg()
  * Fixed sendmsg()/recvmsg() TCP support
  * Fixed several compile warnings
  * Added environment variable to change MTU
* Tue May 12 2015 mpluskal@suse.com
- Rename rpmlintrc so that it complies packaging conventions
* Mon May 11 2015 mpluskal@suse.com
- Mention rpmlintrc as source
* Mon May 11 2015 asn@cryptomilk.org
- Revert library package.
* Mon May 11 2015 asn@cryptomilk.org
- Revert package split
- Require pkg-config and cmake
* Tue May  5 2015 mpluskal@suse.com
- Cleanup spec file
- Use %%cmake install macro
- Split package
- Remove rpmlintrc
* Mon Feb 23 2015 asn@cryptomilk.org
- Update to version 1.1.3
  * Added support for address sanitizer.
  * Fixed leaking of memory and fds of stale sockets.
  * Fixed the library loading code.
* Thu Oct  2 2014 asn@cryptomilk.org
- Update to version 1.1.2
  * Added support for fnctl(F_DUPFD).
  * Added support for glibc 2.20.90.
* Thu Sep 11 2014 asn@cryptomilk.org
- Update to version 1.1.1
  * Disable incomplete address in use check in bind().
  * Added support for IP_PKTINFO in recvmsg().
  * Added support for IPV6_PKTINFO in recvmsg().
  * Added support for IP_RECVDSTADDR in recvmsg() on BSD.
  * Added support for more socket options in getsockopt().
  * Added support for bindresvport().
  * Fixed rebinding on connect().
  * Fixed sockaddr buffer truncation in getsockname() and getpeername().
  * Fixed special cases in bind().
  * Fixed loading libc on some platforms.
  * Fixed memory leaks
  * Fixed calling open from libc.
  * Fixed loading libc functions on some platforms.
* Thu Feb 13 2014 asn@cryptomilk.org
- Initial package.
